@@ -4,7 +4,7 @@
 
 ;; Author: Claire Rodriguez <yewscion@gmail.com>
 ;; Keywords: lisp
-;; Version: 0.0.3
+;; Version: 0.0.4
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -919,5 +919,38 @@ Relies on and modifies current buffer state, undefined return value."
     (insert (cdr255:eval-prior-sexp-to-string))
     (delete-region (car coords) (cdr coords))))
 
+(defun cdr255:copy-cleaned-up-string (&optional str)
+  "Transliterates a `dirty' string, STR, into one which has been cleaned up.
+
+This is an ACTION.
+
+Arguments
+=========
+
+STR<string>: An optional string which will be used (if it is supplied)
+as the 'dirty' string. If `NIL', then the region is used as a string instead.
+
+Returns
+=======
+
+A version of the `dirty' string with a bunch of the difficult-to-parse
+characters replaced, and transformed to all lower case.
+
+Impurities
+==========
+
+Can rely on current region. If optional STR argument is specified, this is a CALCULATION."
+
+  (interactive)
+  (let ((str (if str str (buffer-substring-no-properties (region-beginning) (region-end)))))
+    (kill-new (downcase (replace-regexp-in-string "[!?:;\",.<>()+=@#$%^&*~`|\\]" "_"
+                              (replace-regexp-in-string "[ 	]" "-"
+                                                        (replace-regexp-in-string
+                                                         "[_']" "" str)))))))
+
 (provide 'cdr255)
 ;;; cdr255.el ends here
+
+
+
+
